@@ -2,6 +2,7 @@ use syn::{Attribute, Expr};
 
 pub struct FieldAttributes {
     pub default: Option<Expr>,
+    pub hidden: bool,
     pub use_into: bool,
     pub validator: Option<Expr>,
     pub documents: Vec<Attribute>,
@@ -11,6 +12,7 @@ impl Default for FieldAttributes {
     fn default() -> Self {
         FieldAttributes {
             default: None,
+            hidden: false,
             use_into: false,
             validator: None,
             documents: vec![],
@@ -27,6 +29,8 @@ impl From<Vec<Attribute>> for FieldAttributes {
                     unimplemented!("Duplicated `default` attributes.")
                 }
                 parse_default(attr, &mut attributes)
+            } else if attr.path.is_ident("hidden") {
+                attributes.hidden = true;
             } else if attr.path.is_ident("into") {
                 attributes.use_into = true
             } else if attr.path.is_ident("validator") {
@@ -35,7 +39,10 @@ impl From<Vec<Attribute>> for FieldAttributes {
                 attributes.documents = get_documents(&attrs);
             }
         });
-        attributes
+        match attributes.validate() {
+            Ok(_) => attributes,
+            Err(e) => unimplemented!("{}", e),
+        }
     }
 }
 
@@ -58,3 +65,15 @@ pub fn get_documents(attrs: &[Attribute]) -> Vec<Attribute> {
 
     documents
 }
+
+impl FieldAttributes {
+    fn validate(&self) -> Result<(), String> {
+        if self.hidden && self.default.is_none() {
+            Err(String::from(
+                "`hidden` attribute requires `default` attribute.",
+            ))
+        } else {
+            Ok(())
+        }
+    }
+}
